@@ -114,15 +114,6 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function() {
     LOG("BlockList Global gABI: XPCOM ABI unknown.");
   }
 
-#ifdef XP_MACOSX
-  // Mac universal build should report a different ABI than either macppc
-  // or mactel.
-  let macutils = Cc["@mozilla.org/xpcom/mac-utils;1"].
-                 getService(Ci.nsIMacUtils);
-
-  if (macutils.isUniversalBinary)
-    abi += "-u-" + macutils.architecturesInBinary;
-#endif
   return abi;
 });
 
